@@ -8,7 +8,6 @@ from ..utils import (
     process_ok,
     process_step,
     create_folder,
-    in_virtualenv,
     success_message,
     make_compatible,
     hl,
@@ -30,14 +29,11 @@ def startapp():
 
 @startapp.command("startapp")
 def startapp_command():
-    if not in_virtualenv():
-        raise Exception("You must be in virtual environment to run")
-    
     processes = []
     process_ok(processes)
 
     # Taking app name
-    app_name = take_input("Enter name for app:")
+    app_name = make_compatible(take_input("Enter name for app:"))
 
     # Creating app folder
     prj_name = PSMReader().get_config().get('PROJECT_NAME', None)
