@@ -8,7 +8,6 @@ from ..utils import (
     process_ok,
     process_step,
     create_folder,
-    in_virtualenv,
     success_message,
     make_compatible,
     hl
@@ -30,9 +29,6 @@ def startproject():
 
 @startproject.command("startproject")
 def startproject_command():
-    if not in_virtualenv():
-        raise Exception("You must be in virtual environment to run")
-    
     processes = []
     process_ok(processes)
 
